Crate mraphics_core

Crate mraphics_core 

Modules

anim_curve
constants
math_oper

Structs

Action
BasicMaterial
Bundle
Color
Conveyor
ConveyorManager
Cube
CustomIndices
GadgetData
GadgetDescriptor
GadgetIndex
GeometryView
A view of geometric data that can be consumed by shaders.
LogicalTimeline
MaterialView
MatrixTransform
Mesh
MeshAnimation
MeshBox
A type-erased container for storing any type that implements MeshLike.
MeshHandle
MeshPool
Mobject2DMaterial
Material used for rendering [Mobject2DStroke] objects.
MoveTo
Shifts the mesh to the specific place
MraphicsID
MultiColoredMaterial
PerspectiveCamera
PhysicalTimeline
PipelineManager
PointwiseTransform
RenderInstance
Renderer
RotateAxisAngle
Rotates the mesh around a given axis by a given angle.
ScaleBy
ScaleTo
Scene
Sphere
Vertices
The minimal implementation of Geometry

Enums

ColorError
ConveyorError
GeometryIndices
GeometryViewError
TimelineState

Traits

AllowedIndexFormat
Animation
Camera
ColorComponent
Geometry
A trait for objects that can both initialize and update a GeometryView.
InstanceUpdater
Interpolatable
Material
MeshLike
Representable
A trait that specifies a struct can both:
Timeline
Transformable
Requriements to perform a PointwiseTransform or MatrixTransform