GeometryView

Struct GeometryView 

pub struct GeometryView {
    pub attributes: Vec<GadgetData>,
    pub uniforms: Vec<GadgetData>,
    pub indices: GeometryIndices,
    /* private fields */
}
A view of geometric data that can be consumed by shaders.

This struct represents a collection of attributes, uniforms, and indices that define a geometry.

Fields

attributes: Vec<GadgetData>

Vertex attributes of the geometry (e.g., position, normal, color).

uniforms: Vec<GadgetData>

Uniform variables of the geometry.

indices: GeometryIndices

Index buffer specifying how vertices are connected.

Implementations

Source

impl GeometryView

pub fn new() -> Self

pub fn with_indices(self, indices: GeometryIndices) -> Self

pub fn with_attributes(self, attributes: Vec<GadgetData>) -> Self

pub fn with_uniforms(self, uniforms: Vec<GadgetData>) -> Self

pub fn add_attribute(&mut self, label: &str, index: GadgetIndex, data: Vec<u8>)

pub fn get_attribute( &self, label: &str, ) -> Result<&GadgetData, GeometryViewError>

pub fn get_attribute_mut( &mut self, label: &str, ) -> Result<&mut GadgetData, GeometryViewError>

pub fn set_attribute( &mut self, label: &str, data: Vec<u8>, ) -> Result<(), GeometryViewError>

pub fn get_uniform(&self, label: &str) -> Result<&GadgetData, GeometryViewError>

pub fn get_uniform_mut( &mut self, label: &str, ) -> Result<&mut GadgetData, GeometryViewError>

pub fn add_uniform(&mut self, label: &str, index: GadgetIndex, data: Vec<u8>)

pub fn set_uniform( &mut self, label: &str, data: Vec<u8>, ) -> Result<(), GeometryViewError>

pub fn reset_vertices(&mut self)

pub fn reset_uniforms(&mut self)