pub struct MeshBox { /* private fields */ }Expand description
A type-erased container for storing any type that implements MeshLike.
Similar to Box<dyn Any>.
Implementations
Sourceimpl MeshBox
impl MeshBox
pub fn new<M: MeshLike + 'static>(mesh: M) -> Self
Sourcepub fn downcast_ref<M: MeshLike + 'static>(&self) -> Option<&M>
pub fn downcast_ref<M: MeshLike + 'static>(&self) -> Option<&M>
Attempts to downcast the stored mesh to a reference of given type M.
Returns Some(&M) if the types match, None otherwise.
Sourcepub fn downcast_ref_unchecked<M: MeshLike + 'static>(&self) -> &M
pub fn downcast_ref_unchecked<M: MeshLike + 'static>(&self) -> &M
Downcasts the stored mesh to a reference of type M without type checking.
Safety
Caller must ensure the stored mesh is actually of type M.
Incorrect usage leads to undefined behavior.
Sourcepub fn downcast_mut<M: MeshLike + 'static>(&mut self) -> Option<&mut M>
pub fn downcast_mut<M: MeshLike + 'static>(&mut self) -> Option<&mut M>
Attempts to downcast the stored mesh to a mutable reference of given type M.
Returns Some(&mut M) if the types match, None otherwise.
Sourcepub fn downcast_mut_unchecked<M: MeshLike + 'static>(&mut self) -> &mut M
pub fn downcast_mut_unchecked<M: MeshLike + 'static>(&mut self) -> &mut M
Downcasts the stored mesh to a mutable reference of type M without type checking.
Safety
Caller must ensure the stored mesh is actually of type M.
Incorrect usage leads to undefined behavior.
Sourcepub fn update_mesh(&mut self)
pub fn update_mesh(&mut self)
Triggers MeshLike::update for the stored mesh.
Sourcepub fn update_instance(&mut self, instance: &mut RenderInstance)
pub fn update_instance(&mut self, instance: &mut RenderInstance)
Triggers [InstanceUpdater::update_instance] for the stored mesh.