pub struct Mobject2DMaterial {}Expand description
Material used for rendering [Mobject2DStroke] objects.
Camera Compatibility
This material is specifically designed to work with crate::PerspectiveCamera.
Using it with other camera types will result in incorrect rendering.
Implementations