Modules
Structs
- Action
- Basic
Material - Bundle
- Color
- Conveyor
- Conveyor
Manager - Cube
- Custom
Indices - Gadget
Data - Gadget
Descriptor - Gadget
Index - Geometry
View - A view of geometric data that can be consumed by shaders.
- Logical
Timeline - Material
View - Matrix
Transform - Mesh
- Mesh
Animation - MeshBox
- A type-erased container for storing any type that implements
MeshLike. - Mesh
Handle - Mesh
Pool - Mobject2D
Material - Material used for rendering [
Mobject2DStroke] objects. - MoveTo
- Shifts the mesh to the specific place
- MraphicsID
- Multi
Colored Material - Perspective
Camera - Physical
Timeline - Pipeline
Manager - Pointwise
Transform - Render
Instance - Renderer
- Rotate
Axis Angle - Rotates the mesh around a given axis by a given angle.
- ScaleBy
- ScaleTo
- Scene
- Sphere
- Vertices
- The minimal implementation of
Geometry
Enums
Traits
- Allowed
Index Format - Animation
- Camera
- Color
Component - Geometry
- A trait for objects that can both initialize and update a
GeometryView. - Instance
Updater - Interpolatable
- Material
- Mesh
Like - Representable
- A trait that specifies a struct can both:
- Timeline
- Transformable
- Requriements to perform a
PointwiseTransformorMatrixTransform